@@ -1,3 +1,5 @@
+import logging
+
 from google.cloud import bigquery
 from datetime import datetime
 import json
@@ -12,7 +14,7 @@ from airflow_commons.internal.bigquery.constants import (
     MEGABYTES_BILLED_DENOMINATOR,
 )
 from airflow_commons.internal.util.time_utils import get_interval_duration
-from airflow_commons.logger import LOGGER
+from airflow_commons.logger import get_logger
 from airflow_commons.resources.bigquery import (
     GET_COLUMN_NAMES_SQL_FILE,
     GET_TABLE_NAMES_SQL_FILE,
@@ -26,6 +28,8 @@ from airflow_commons.internal.bigquery.defaults import (
 from airflow_commons.internal.util.file_utils import read_sql
 from airflow_commons.resources.glossary import COMMA, SQL_QUOTATION, WHITE_SPACE
 
+logger = get_logger("BigqueryCore")
+
 
 def get_table_ref(client: bigquery.Client, dataset_id: str, table_id: str):
     """
@@ -83,19 +87,19 @@ def query(
     :return: job result
     """
     timer_start = datetime.now()
-    LOGGER.info(f"SQL TO RUN: ##  {sql}  ##")
+    logger.debug(f"SQL TO RUN: ##  {sql}  ##")
     query_job = client.query(
         sql, location=location, timeout=timeout, job_config=job_config
     )
     result = query_job.result()
     timer_end = datetime.now()
     if query_job.state == "DONE":
-        LOGGER.info(
+        logger.info(
             f"Query Job ID: {query_job.job_id}, Elapsed Time: {get_interval_duration(timer_start, timer_end)}, Job Priority: {query_job.priority}, Total MBytes Billed: {query_job.total_bytes_billed / MEGABYTES_BILLED_DENOMINATOR}, Number of Rows Affected: {query_job.num_dml_affected_rows}"
         )
         return result
     else:
-        LOGGER.error(
+        logger.error(
             f"Query Job ID: {query_job.job_id}, Job Priority: {query_job.priority}, Elapsed Time: {get_interval_duration(timer_start, timer_end)}"
         )
         raise Exception("Job is not Done.")
@@ -180,7 +184,10 @@ def select(
             ensure_ascii=False,
         )
     elif return_type == "dict":
-        return result.to_dataframe().to_dict(orient="records")
+        df = result.to_dataframe()
+        print("-----------------mem usage------------------------")
+        print(df.memory_usage())
+        return df.to_dict(orient="records")
     elif return_type == "dataframe":
         return result.to_dataframe()
     elif return_type == "csv":
