@@ -86,7 +86,7 @@ class SalesForceOperator(object):
         :return:
         """
         start = datetime.now()
-        self.logger.info("Async operation started...")
+        self.logger.debug("Async operation started...")
         self.connection.check_and_refresh_token()
         url = get_async_operation_url(
             base_url=self.connection.rest_instance_url, key=key
@@ -123,7 +123,7 @@ class SalesForceOperator(object):
         :return:
         """
         start = datetime.now()
-        self.logger.info("Sync upsert operation started...")
+        self.logger.debug("Sync upsert operation started...")
         self.connection.check_and_refresh_token()
         url = get_sync_operation_url(
             base_url=self.connection.rest_instance_url, key=key
@@ -160,7 +160,7 @@ class SalesForceOperator(object):
         :return:
         """
         start = datetime.now()
-        self.logger.info("Sync fetch operation started...")
+        self.logger.debug("Sync fetch operation started...")
         self.connection.check_and_refresh_token()
         url = get_fetch_operation_url(
             base_url=self.connection.rest_instance_url, key=key, filter=filter
